.. geochemistrypy_test documentation master file, created by
   sphinx-quickstart on Sun Oct 23 18:52:20 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Geochemistry π 
=======================================================================================

.. toctree::
   :maxdepth: 3
   :caption: Home

   Introduction <Home/Introduction.md>
   Change Log <Home/CHANGELOG.md>

.. toctree::
   :maxdepth: 3
   :caption: For User

   User Guide <For User/User Guide.md>
   Installation Manual <For User/Installation Manual.md>
   Model Example <model example.rst>    
   Contact Us <contact us.rst>
   Docs Link <For User/User Docs link.md>

.. toctree::
   :maxdepth: 3
   :caption: For Developer

   Developer Guide <For Developer/Developer Guide/Developer Manual.md>
   Contributing <contributing.rst>
   Deployment <deployment.rst>
   Complete Pull Request <For Developer/A Completed Pull Request.md>
   Add New Model To Framework <For Developer/Add New Model To Framework.md>
   Docs Link <For Developer/Developer Docs link.md>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
